@@ -7,6 +7,8 @@ from django.core.urlresolvers import reverse
 import models as mymodels
 import forms as myforms
 
+from engine import expire_view_cache
+
 
 def make_published(self, request, queryset):
     rows_updated = queryset.update(status=1)
@@ -45,8 +47,18 @@ class PostAdminForm(admin.ModelAdmin):
     if "rgallery" in conf.INSTALLED_APPS:
         filter_horizontal = ['photo', 'video']
 
-    """ http://www.b-list.org/weblog/2008/dec/24/admin/ """
+    """
+    On Post save we want to save the user that is editing the post [1] and we
+    want to regenerate both caches [2] (blog-index and post-detail pages). To
+    see how cache and memcache works take a look on engine.expire_view_cache
+
+    1. http://www.b-list.org/weblog/2008/dec/24/admin/
+    2. http://stackoverflow.com/questions/2268417/expire-a-view-cache-in-django
+    """
+
     def save_model(self, request, obj, form, change):
+        expire_view_cache("app_blog-index")
+        expire_view_cache("app_blog-post-detail", [obj.slug])
         if not change:
             obj.user = request.user
         obj.save()
